import { SeriesStyle } from '../../interfaces/SeriesStyle';
import { SeriesType } from '../../interfaces/SeriesType';
export class ElementStrategyFactory {
    static get(primaryType) {
        switch (primaryType) {
            case SeriesType.Line:
                return new LineStrategyFactory();
            case SeriesType.Stacked:
                return new StackedStrategyFactory();
            case SeriesType.Column:
            default:
                return new ColumnStrategyFactory();
        }
    }
}
export class LineStrategyFactory {
    get(style) {
        switch (style) {
            case SeriesStyle.Multi:
                return new MultiLineSeries();
            case SeriesStyle.Single:
            default:
                return new SingleLineSeries();
        }
    }
}
export class ColumnStrategyFactory {
    get(style) {
        switch (style) {
            case SeriesStyle.Multi:
                return new MultiColumnSeries();
            case SeriesStyle.Single:
            default:
                return new SingleColumnSeries();
        }
    }
}
export class StackedStrategyFactory {
    get() {
        return new StackedSeries();
    }
}
class ChartStrategy {
}
export class SingleSeriesChartStrategy {
    arrow() {
        return true;
    }
    flatten(data) {
        return data;
    }
    getPopoverEl(svg, index) {
        return svg.select('.point-' + index).nodes()[0];
    }
    getPopoverPlacement() {
        return 'top';
    }
    getSeriesStyle() {
        return SeriesStyle.Single;
    }
    getTargetingData(data) {
        return data;
    }
    isMultiSeries() {
        return false;
    }
}
export class MultiSeriesChartStrategy {
    arrow() {
        return false;
    }
    flatten(data) {
        return [].concat(...data);
    }
    getPopoverEl(svg, index) {
        return svg.select('.scrubber-' + index).nodes()[0];
    }
    getPopoverPlacement() {
        return 'right';
    }
    getSeriesStyle() {
        return SeriesStyle.Multi;
    }
    getTargetingData(data) {
        return data[0];
    }
    isMultiSeries() {
        return true;
    }
}
export class StackedSeries extends MultiSeriesChartStrategy {
}
export class SingleLineSeries extends SingleSeriesChartStrategy {
}
export class MultiLineSeries extends MultiSeriesChartStrategy {
}
export class SingleColumnSeries extends SingleSeriesChartStrategy {
}
export class MultiColumnSeries extends MultiSeriesChartStrategy {
    arrow() {
        return true;
    }
    getPopoverPlacement() {
        return 'top';
    }
}
