import { h } from '../anjuna-charts.core.js';

import { b as SeriesStyle, a as ChartDataService } from './chunk-15621c8f.js';

class Delta {
    componentWillLoad() {
        this.deltaHandler(this.delta);
    }
    deltaHandler(newValue) {
        if (!newValue) {
            return;
        }
        if (newValue < 0) {
            this.deltaDisplay = (newValue * -1).toString();
            this.positive = false;
            this.positiveColorScheme = !!this.netNegative;
        }
        else {
            this.deltaDisplay = newValue.toString();
            this.positive = true;
            this.positiveColorScheme = !this.netNegative;
        }
    }
    periodFormatter(period) {
        switch (period) {
            case 0:
                return 'MoM';
            case 1:
                return 'YoY';
            case 2:
                return 'WoW';
            case 3:
                return 'DoD';
            default:
                return '';
        }
    }
    hostData() {
        return {
            'class': {
                'anj-delta-negative': !this.positiveColorScheme,
                'anj-has-data': !!this.delta
            }
        };
    }
    render() {
        return (this.delta && this.deltaDisplay) ? (h("span", null,
            this.positive ? h("i", { class: "z-icon-arrow-up" }) : h("i", { class: "z-icon-arrow-down" }),
            this.deltaDisplay,
            "% ",
            this.periodFormatter(this.period))) : undefined;
    }
    static get is() { return "anj-delta"; }
    static get properties() { return {
        "delta": {
            "type": Number,
            "attr": "delta",
            "watchCallbacks": ["deltaHandler"]
        },
        "netNegative": {
            "type": Boolean,
            "attr": "net-negative"
        },
        "period": {
            "type": Number,
            "attr": "period"
        }
    }; }
    static get style() { return "anj-delta{color:var(--anj-success);display:inline-block;white-space:nowrap}anj-delta.anj-delta-negative{color:var(--anj-danger)}"; }
}

class PopoverContentMulti {
    constructor() {
        this.displays = [];
    }
    activeDataHandler(newValue) {
        if (newValue.seriesStyle !== SeriesStyle.Multi) {
            return;
        }
        if (newValue.axisConfigs.x.labelType === 'date') {
            this.period = ChartDataService.calculateInterval(newValue.data[0]);
        }
        this.displays = newValue.data
            .map((d, i) => {
            const x = d[newValue.activeIndex].x;
            const y = d[newValue.activeIndex].y;
            this.xDisplayValue = ChartDataService.xFormatter(this.period, newValue.axisConfigs.x, x);
            return {
                color: newValue.seriesMeta[i].color,
                name: newValue.seriesMeta[i].name,
                netNegative: newValue.seriesMeta[i].netNegative,
                x,
                y,
                yDisplayValue: ChartDataService.yFormatter(newValue.axisConfigs.y, y),
                delta: PopoverContentMulti.getDelta(d, newValue.activeIndex)
            };
        });
    }
    static getDelta(data, activeIndex) {
        if (activeIndex === 0) {
            return undefined;
        }
        const prevY = parseInt(data[activeIndex - 1].y, 10);
        const y = parseInt(data[activeIndex].y, 10);
        const modifier = (y - prevY >= 0) ? 1 : -1;
        return Math.round(100 * Math.abs(y - prevY) / Math.abs(prevY) * modifier);
    }
    getStyle(color) {
        return {
            'background-color': color
        };
    }
    render() {
        return (this.activeData) ? [
            h("div", null,
                h("div", null, this.xDisplayValue),
                h("table", { class: "anj-metric-wrapper" }, this.displays.map((disp) => h("tr", null,
                    h("td", null,
                        h("span", { class: "anj-legend-color", style: this.getStyle(disp.color) })),
                    h("td", { class: "anj-label" }, disp.name),
                    h("td", { class: "anj-value" }, disp.yDisplayValue),
                    h("td", null,
                        h("anj-delta", { delta: disp.delta, period: this.period, netNegative: disp.netNegative }))))))
        ] : undefined;
    }
    static get is() { return "anj-popover-content-multi"; }
    static get properties() { return {
        "activeData": {
            "type": "Any",
            "attr": "active-data",
            "watchCallbacks": ["activeDataHandler"]
        }
    }; }
    static get style() { return "anj-popover-content-multi{color:var(--anj-neutral);display:block;line-height:1;margin:.5rem 1rem;text-align:center;white-space:nowrap}anj-popover-content-multi .anj-value{color:var(--anj-primary);display:block;font-size:1rem;padding:.5rem .5rem 0;padding-left:1rem}anj-popover-content-multi .anj-label{max-width:9rem;overflow:hidden;text-overflow:ellipsis;text-transform:capitalize}\@media (min-width:576px){anj-popover-content-multi .anj-label{max-width:12rem}}anj-popover-content-multi .anj-legend-color{border-radius:50%;display:block;height:50%;left:0;margin:.5rem .25rem 0 0;opacity:1;position:absolute;top:0;width:1rem}anj-popover-content-multi .anj-metric-wrapper{text-align:left}anj-popover-content-multi .anj-metric-wrapper tr{border-bottom:1px solid var(--anj-border)}anj-popover-content-multi .anj-metric-wrapper tr:last-child{border-bottom:0}anj-popover-content-multi .anj-metric-wrapper td{padding:.5rem;position:relative}"; }
}

class PopoverContentSingle {
    activeDataHandler(newValue) {
        if (newValue.seriesStyle !== SeriesStyle.Single) {
            return;
        }
        const x = newValue.data[newValue.activeIndex].x;
        const y = newValue.data[newValue.activeIndex].y;
        if (newValue.axisConfigs.x.labelType === 'date') {
            this.period = ChartDataService.calculateInterval(newValue.data);
            this.delta = PopoverContentSingle.getDelta(newValue);
        }
        this.xDisplayValue = ChartDataService.xFormatter(this.period, newValue.axisConfigs.x, x);
        this.yDisplayValue = ChartDataService.yFormatter(newValue.axisConfigs.y, y);
    }
    static getDelta(activeData) {
        if (activeData.activeIndex === 0) {
            return undefined;
        }
        const prevY = parseInt(activeData.data[activeData.activeIndex - 1].y, 10);
        const y = parseInt(activeData.data[activeData.activeIndex].y, 10);
        return Math.round((1 - (y / prevY)) * -100);
    }
    render() {
        return (this.activeData) ? [
            h("div", null,
                h("div", null, this.xDisplayValue),
                h("div", { class: "anj-value" }, this.yDisplayValue),
                h("anj-delta", { delta: this.delta, period: this.period }))
        ] : undefined;
    }
    static get is() { return "anj-popover-content-single"; }
    static get properties() { return {
        "activeData": {
            "type": "Any",
            "attr": "active-data",
            "watchCallbacks": ["activeDataHandler"]
        }
    }; }
    static get style() { return "anj-popover-content-single{color:var(--anj-neutral);display:block;line-height:1;margin:.5rem 1rem;text-align:center;white-space:nowrap}anj-popover-content-single .anj-value{color:var(--anj-primary);display:block;font-size:1.5rem;padding:.5rem .5rem 0}anj-popover-content-single anj-delta.anj-has-data{border-top:1px solid var(--anj-border);margin-top:.75rem;padding-top:.5rem}"; }
}

export { Delta as AnjDelta, PopoverContentMulti as AnjPopoverContentMulti, PopoverContentSingle as AnjPopoverContentSingle };
